// $Id: LuceneExample.java 10479 2009-07-10 09:51:07Z chris $

import org.apache.lucene.document.*;
import org.apache.lucene.analysis.standard.*;
import org.apache.lucene.index.*;
import org.apache.lucene.queryParser.*;
import org.apache.lucene.queryParser.ParseException;
import org.apache.lucene.search.*;
import org.faceless.pdf2.*;
import java.io.*;
import java.util.*;

/**
 * A Simple example demonstrating how to index then search a PDF using the
 * Apache Lucene library. The only PDF-specific bit is the "createIndex" method.
 */
public class LuceneExample
{
    public static void main(String[] args) throws Exception {
        if (args.length==0) {
            System.err.println("Usage: java LuceneExample <file.pdf>\n\n");
            System.exit(1);
        }
        String index = "luceneindex";           // path to store the index in
        createIndex(args[0], index);
        searchIndex("World", index);
    }

    /**
     * Create the index. This has the only PDF library specific
     * code in this example - it calls the PDFParser.getLuceneDocument
     * method.
     */
    static void createIndex(String file, String index) throws IOException {
        PDF pdf = new PDF(new PDFReader(new File(file)));
        PDFParser parser = new PDFParser(pdf);

        IndexWriter writer = new IndexWriter(index, new StandardAnalyzer(), true);
        Document doc = parser.getLuceneDocument(true, true, true);
        writer.addDocument(doc);
        writer.optimize();
        writer.close();
    }

    /**
     * Search the index for the specified text
     */
    static void searchIndex(String querystring, String index) throws IOException, ParseException {
        IndexSearcher indexSearcher = new IndexSearcher(index);
        QueryParser parser = new QueryParser("all", new StandardAnalyzer());
        Query query = parser.parse(querystring);
        Hits hits = indexSearcher.search(query);
        int hitCount = hits.length();
        if (hitCount>10) hitCount = 10;
        for(int i=0; i<hitCount; i++){
            Document doc = hits.doc(i);
            System.out.println(doc.get("body"));
        }
    }
}
