// $Id: PageNext.java 14143 2011-10-25 17:23:02Z mike $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.PDFPage;
import org.faceless.pdf2.PDF;
import javax.swing.*;

/**
 * Create a button to jump to the next page.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">PageNext</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.8
 */
public class PageNext extends ViewerWidget implements DocumentPanelListener
{
    public PageNext() {
        super("PageNext");
        setButton("Navigation.ltr", "resources/icons/NextPage.png", "PDFViewer.tt.PageNext");
        setMenu("View\tGoTo\tNextPage");
    }

    public void action(ViewerEvent event) {
        DocumentPanel docpanel = event.getDocumentPanel();
        PDFPage page = docpanel.getViewport().getRenderingPage();
        int pagenumber = page==null ? 0 : page.getPageNumber() - 1;
        if (pagenumber < docpanel.getPDF().getNumberOfPages() - 1) {
            event.getDocumentPanel().setPageNumber(pagenumber + 1);
        }
    }

    public void initialize(PDFViewer viewer) {
        super.initialize(viewer);
        viewer.addDocumentPanelListener(this);
    }

    public void documentUpdated(DocumentPanelEvent event) {
        if (event.getType()=="pageChanged" || event.getType()=="activated") {
            PDF pdf = event.getDocumentPanel().getPDF();
            boolean enabled = pdf!=null && event.getDocumentPanel().getPageNumber() < pdf.getNumberOfPages()-1;
            event.getDocumentPanel().getViewer().getNamedComponent("ButtonPageNext").setEnabled(enabled);
            event.getDocumentPanel().getViewer().getNamedComponent("MenuPageNext").setEnabled(enabled);
        }
    }
}
